package com.bonus.material.basic.service.impl;

import java.util.List;
import com.bonus.common.core.exception.ServiceException;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.basic.mapper.BmSlideShowMapper;
import com.bonus.material.basic.domain.BmSlideShow;
import com.bonus.material.basic.service.IBmSlideShowService;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author xsheng
 * @date 2025-01-15
 */
@Service
public class BmSlideShowServiceImpl implements IBmSlideShowService {
    @Autowired
    private BmSlideShowMapper bmSlideShowMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public BmSlideShow selectBmSlideShowById(Long id) {
        return bmSlideShowMapper.selectBmSlideShowById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param bmSlideShow 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<BmSlideShow> selectBmSlideShowList(BmSlideShow bmSlideShow) {
        return bmSlideShowMapper.selectBmSlideShowList(bmSlideShow);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param bmSlideShow 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertBmSlideShow(BmSlideShow bmSlideShow) {
        bmSlideShow.setCreateTime(DateUtils.getNowDate());
        try {
            return bmSlideShowMapper.insertBmSlideShow(bmSlideShow);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param bmSlideShow 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateBmSlideShow(BmSlideShow bmSlideShow) {
        bmSlideShow.setUpdateTime(DateUtils.getNowDate());
        try {
            return bmSlideShowMapper.updateBmSlideShow(bmSlideShow);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteBmSlideShowByIds(Long[] ids) {
        return bmSlideShowMapper.deleteBmSlideShowByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteBmSlideShowById(Long id) {
        return bmSlideShowMapper.deleteBmSlideShowById(id);
    }
}
