package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.material.basic.domain.BmSlideShow;
import com.bonus.material.basic.service.IBmSlideShowService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author xsheng
 * @date 2025-01-15
 */
@Api(tags = "【请填写功能名称】接口")
@RestController
@RequestMapping("/bm_slide_show")
public class BmSlideShowController extends BaseController {
    @Autowired
    private IBmSlideShowService bmSlideShowService;

    /**
     * 查询【请填写功能名称】列表
     */
    @ApiOperation(value = "查询【请填写功能名称】列表")
    //@RequiresPermissions("basic:show:list")
    @GetMapping("/list")
    public TableDataInfo list(BmSlideShow bmSlideShow) {
        startPage();
        List<BmSlideShow> list = bmSlideShowService.selectBmSlideShowList(bmSlideShow);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @ApiOperation(value = "导出【请填写功能名称】列表")
    @PreventRepeatSubmit
    //@RequiresPermissions("basic:show:export")
    @SysLog(title = "【请填写功能名称】", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出【请填写功能名称】")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmSlideShow bmSlideShow) {
        List<BmSlideShow> list = bmSlideShowService.selectBmSlideShowList(bmSlideShow);
        ExcelUtil<BmSlideShow> util = new ExcelUtil<BmSlideShow>(BmSlideShow.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @ApiOperation(value = "获取【请填写功能名称】详细信息")
    //@RequiresPermissions("basic:show:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmSlideShowService.selectBmSlideShowById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @ApiOperation(value = "新增【请填写功能名称】")
    @PreventRepeatSubmit
    //@RequiresPermissions("basic:show:add")
    @SysLog(title = "【请填写功能名称】", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增【请填写功能名称】")
    @PostMapping
    public AjaxResult add(@RequestBody BmSlideShow bmSlideShow) {
        try {
            return toAjax(bmSlideShowService.insertBmSlideShow(bmSlideShow));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改【请填写功能名称】
     */
    @ApiOperation(value = "修改【请填写功能名称】")
    @PreventRepeatSubmit
    //@RequiresPermissions("basic:show:edit")
    @SysLog(title = "【请填写功能名称】", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改【请填写功能名称】")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BmSlideShow bmSlideShow) {
        try {
            return toAjax(bmSlideShowService.updateBmSlideShow(bmSlideShow));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除【请填写功能名称】
     */
    @ApiOperation(value = "删除【请填写功能名称】")
    @PreventRepeatSubmit
    //@RequiresPermissions("basic:show:remove")
    @SysLog(title = "【请填写功能名称】", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除【请填写功能名称】")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmSlideShowService.deleteBmSlideShowByIds(ids));
    }
}
